searchData={"content_type":"text/markdown","items":[{"doc":"Used to create IDs for LiveViews and LiveComponents that can be used as a target for `send_info/2` and `send_info_after/3`","ref":"LiveMessage.Id.html","title":"LiveMessage.Id","type":"module"},{"doc":"","ref":"LiveMessage.Id.html#for_component/2","title":"LiveMessage.Id.for_component/2","type":"function"},{"doc":"","ref":"LiveMessage.Id.html#for_live_view/0","title":"LiveMessage.Id.for_live_view/0","type":"function"},{"doc":"A struct representing the ID of a LiveComponent that can be used as a target for `send_info/2` and `send_info_after/3`","ref":"LiveMessage.Id.LiveComponentId.html","title":"LiveMessage.Id.LiveComponentId","type":"module"},{"doc":"A struct representing the ID of a LiveView that can be used as a target for `send_info/2` and `send_info_after/3`","ref":"LiveMessage.Id.LiveViewId.html","title":"LiveMessage.Id.LiveViewId","type":"module"},{"doc":"When a LiveComponent has `use LiveMessage.LiveComponent` it will have a `@me` assign that can be used as a target for `send_info/2` and `send_info_after/3`\n\nThis will also allow the LiveComponent to receive messages in `handle_info/3`","ref":"LiveMessage.LiveComponent.html","title":"LiveMessage.LiveComponent","type":"module"},{"doc":"","ref":"LiveMessage.LiveComponent.html#default_update/2","title":"LiveMessage.LiveComponent.default_update/2","type":"function"},{"doc":"","ref":"LiveMessage.LiveComponent.html#update_decorator/4","title":"LiveMessage.LiveComponent.update_decorator/4","type":"function"},{"doc":"When a LiveView has `use LiveMessage.LiveView` it will have a `@me` assign that can be used as a target for `send_info/2` and `send_info_after/3`","ref":"LiveMessage.LiveView.html","title":"LiveMessage.LiveView","type":"module"},{"doc":"","ref":"LiveMessage.LiveView.html#on_mount/4","title":"LiveMessage.LiveView.on_mount/4","type":"function"},{"doc":"The `send_info/2` and `send_info_after/3` functions that are imported into all LiveViews and LiveComponents","ref":"LiveMessage.SendFunctions.html","title":"LiveMessage.SendFunctions","type":"module"},{"doc":"Sends `message` to `target` asynchronously.","ref":"LiveMessage.SendFunctions.html#send_info/2","title":"LiveMessage.SendFunctions.send_info/2","type":"function"},{"doc":"- message: the message to be sent, this can be any term.\n  - target: the LiveMessage.Id of the LiveView or LiveComponent. This can be found using the `@me` assign.\n  - time: time in milliseconds to wait before sending the message.","ref":"LiveMessage.SendFunctions.html#send_info/2-parameters","title":"Parameters - LiveMessage.SendFunctions.send_info/2","type":"function"},{"doc":"Sends `message` to `target` after `time` milliseconds.","ref":"LiveMessage.SendFunctions.html#send_info_after/3","title":"LiveMessage.SendFunctions.send_info_after/3","type":"function"},{"doc":"- message: the message to be sent, this can be any term.\n  - target: the LiveMessage.Id of the LiveView or LiveComponent. This can be found using the `@me` assign.\n  - time: time in milliseconds to wait before sending the message.","ref":"LiveMessage.SendFunctions.html#send_info_after/3-parameters","title":"Parameters - LiveMessage.SendFunctions.send_info_after/3","type":"function"},{"doc":"LiveMessage\n===========\n\n![CI](https://github.com/Dyad-AI/live_message/actions/workflows/ci.yml/badge.svg) [![Hex.pm](https://img.shields.io/hexpm/v/live_message.svg)](https://hex.pm/packages/live_message) [![Documentation](https://img.shields.io/badge/documentation-gray)](https://hexdocs.pm/live_message/)\n\nUnified messaging for LiveViews and LiveComponents, to allow for simple decomposition of LiveViews into LiveComponents.","ref":"readme.html","title":"LiveMessage","type":"extras"},{"doc":"From any LiveView or LiveComponent you can:\n\n```elixir\nsend_info(target, message)\n```\n\nor\n\n```elixir\nsend_info_after(target, message, time)\n```\n\nwhich will trigger a `handle_info/2` in the target LIveView or LiveComponent:\n\n```elixir\ndef handle_info(message, socket) do\n  ....\n  {:noreply, socket}\nend\n```\n\nThe \"target\" here is the ID of the LiveView or LiveComponent available though the `@me` assign, e.g.\n\n```heex\n \n```\n\nThink of `@me` like `@myself` but for live messaging.","ref":"readme.html#usage","title":"Usage - LiveMessage","type":"extras"},{"doc":"LiveComponents are a great way to break up large LiveViews into smaller reusable components. But what happens when your LiveComponents\nget too big? You could break them down into smaller components, but this comes with  a couple of issues:\n\n- LiveComponents get coupled to their parent\n- LiveComponent message handling is coupled to initialisation\n\n##","ref":"readme.html#motivation","title":"Motivation - LiveMessage","type":"extras"},{"doc":"In order for a LiveComponent to communicate to it's parent, it needs to send messages. If it's parent is a LiveView you need `send/2`,\nbut if it's parent is a LiveComponent you need `LiveView.send_update/2`. So a component needs to know what it's parent is and handle that variation.\n\n##","ref":"readme.html#livecomponents-get-coupled-to-their-parent","title":"LiveComponents get coupled to their parent - LiveMessage","type":"extras"},{"doc":"To send a message to a LiveComponent you use `LiveView.send_update/2` and this is handled in the `update/2` function. Typically `update/2`\nis used to set the assigns for the LiveComponent, so for it to also be the message handling function feels like these concerns have not been properly separated:\n\n\n```elixir\ndef update(%{my_message: message}, socket) do\n  # handle message\n  {:ok, socket}\nend\n\ndef update(assigns, socket) do\n  # Initialise state\n  {:ok, socket}\nend\n```\n\n##","ref":"readme.html#livecomponent-message-handling-is-coupled-to-initialisation","title":"LiveComponent message handling is coupled to initialisation - LiveMessage","type":"extras"},{"doc":"LiveMessage solves both these issues by providing a unified way to message LiveViews and LiveComponents that both use `handle_info/2` to handle the messages.","ref":"readme.html#the-solution","title":"The solution - LiveMessage","type":"extras"},{"doc":"The package can be installed by adding `live_message` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:live_message, \"~> 0.1.12\"}\n  ]\nend\n```\n\nNext, add the following `use` statements to your web file in `lib/my_app_web.ex`:\n\n```elixir\n# lib/my_app_web.ex\n\ndef live_view do\n  quote do\n    # ...\n    use LiveMessage.LiveView\n  end\nend\n\ndef live_component do\n  quote do\n    # ...\n    use LiveMessage.LiveComponent\n  end\nend\n```","ref":"readme.html#installation","title":"Installation - LiveMessage","type":"extras"}]}